@@ -29,7 +29,6 @@ use crate::{FallibleIterator, SectionCharacteristics};
 /// let mut pdb = pdb2::PDB::open(file)?;
 ///
 /// let dbi = pdb.debug_information()?;
-
 ///
 /// # let mut count: usize = 0;
 /// let mut modules = dbi.modules()?;
@@ -81,6 +80,7 @@ impl<'s> DebugInformation<'s> {
     /// checked for matching the image.
     ///
     /// [`PDBInformation::age`]: crate::PDBInformation::age
+    #[must_use]
     pub fn age(&self) -> Option<u32> {
         match self.header.age {
             0 => None,
@@ -88,6 +88,18 @@ impl<'s> DebugInformation<'s> {
         }
     }
 
+    /// Returns whether or not this PDB has been marked as stripped. Stripped PDBs do not contain
+    /// type information, line number information, or per-object CV symbols.
+    ///
+    /// This flag is set when a PDB is written with [/PDBSTRIPPED] by MSVC.
+    ///
+    /// [/PDBSTRIPPED]: https://learn.microsoft.com/en-us/cpp/build/reference/pdbstripped-strip-private-symbols?view=msvc-170
+    #[must_use]
+    pub fn is_stripped(&self) -> bool {
+        // flags.fStripped
+        (self.header.flags & 0x2) != 0
+    }
+
     /// Returns an iterator that can traverse the modules list in sequential order.
     pub fn modules(&self) -> Result<ModuleIter<'_>> {
         let mut buf = self.stream.parse_buffer();
@@ -107,6 +119,19 @@ impl<'s> DebugInformation<'s> {
         let contributions_buf = buf.take(self.header.section_contribution_size as usize)?;
         DBISectionContributionIter::parse(contributions_buf.into())
     }
+
+    /// Returns an iterator that can traverse the section map in sequential order. Also known as the "OMF Segment map".
+    pub fn section_map(&self) -> Result<DBISectionMapIter<'_>> {
+        let mut buf = self.stream.parse_buffer();
+        // drop the header, modules list, and section contributions list
+        let offset = self.header_len
+            + self.header.module_list_size as usize
+            + self.header.section_contribution_size as usize;
+
+        buf.take(offset)?;
+        let section_map_buf = buf.take(self.header.section_map_size as usize)?;
+        DBISectionMapIter::parse(section_map_buf.into())
+    }
 }
 
 /// The version of the PDB format.
@@ -234,7 +259,7 @@ impl DBIHeader {
             reserved: buf.parse_u32()?,
         };
 
-        if header.signature != u32::max_value() {
+        if header.signature != u32::MAX {
             // this is likely a DBIHdr, not a NewDBIHdr
             // it could be promoted:
             //   https://github.com/Microsoft/microsoft-pdb/blob/082c5290e5aff028ae84e43affa8be717aa7af73/PDB/dbi/dbi.cpp#L291-L313
@@ -421,7 +446,7 @@ impl DBISectionContribution {
 /// <https://github.com/Microsoft/microsoft-pdb/blob/082c5290e5aff028ae84e43affa8be717aa7af73/PDB/dbi/dbi.h#L1197>
 #[derive(Debug, Copy, Clone)]
 #[allow(dead_code)] // reason = "unused fields added for completeness"
-pub(crate) struct DBIModuleInfo {
+pub struct DBIModuleInfo {
     /// Currently open module.
     pub opened: u32,
     /// This module's first section contribution.
@@ -484,12 +509,13 @@ pub struct Module<'m> {
 
 impl<'m> Module<'m> {
     /// The `DBIModuleInfo` from the module info substream in the DBI stream.
-    pub(crate) fn info(&self) -> &DBIModuleInfo {
+    pub fn info(&self) -> &DBIModuleInfo {
         &self.info
     }
     /// The module name.
     ///
     /// Usually either a full path to an object file or a string of the form `Import:<dll name>`.
+    #[must_use]
     pub fn module_name(&self) -> Cow<'m, str> {
         self.module_name.to_string()
     }
@@ -498,6 +524,7 @@ impl<'m> Module<'m> {
     /// May be the same as `module_name` for object files passed directly
     /// to the linker. For modules from static libraries, this is usually
     /// the full path to the archive.
+    #[must_use]
     pub fn object_file_name(&self) -> Cow<'m, str> {
         self.object_file_name.to_string()
     }
@@ -566,7 +593,7 @@ impl<'c> DBISectionContributionIter<'c> {
     }
 }
 
-impl<'c> FallibleIterator for DBISectionContributionIter<'c> {
+impl FallibleIterator for DBISectionContributionIter<'_> {
     type Item = DBISectionContribution;
     type Error = Error;
 
@@ -584,6 +611,112 @@ impl<'c> FallibleIterator for DBISectionContributionIter<'c> {
     }
 }
 
+/// See <https://github.com/google/syzygy/blob/8164b24ebde9c5649c9a09e88a7fc0b0fcbd1bc5/syzygy/pdb/pdb_data.h#L172>
+/// Also see <https://www.virtualbox.org/browser/vbox/trunk/include/iprt/formats/codeview.h?rev=93115#L272>
+/// This is also known as OMF Segment Map. In the OMF SegmentMap structure, flags and section_type
+/// are a single 16-bit value.
+#[derive(Debug, Copy, Clone)]
+pub struct DBISectionMapItem {
+    /// flags: 0x1 read, 0x2 write, 0x4 execute, 0x8 32-bit
+    pub flags: u8,
+    /// section_type: 0x1 = SEL, 0x2 = ABS, 0x10 = GROUP
+    pub section_type: u8,
+    /// Overlay number
+    pub overlay: u16,
+    /// group index, 0 if not relevant
+    pub group: u16,
+    /// Technically "frame" in OMF SegmentMap, which is complicated
+    pub section_number: u16,
+    /// Index into name table, or 0xffff
+    pub seg_name_index: u16,
+    /// Index into name table, or 0xffff
+    pub class_name_index: u16,
+    /// RVA offset of this section
+    pub rva_offset: u32,
+    /// Length of this section
+    pub section_length: u32,
+}
+
+/// Section flag values for the `DBISectionMapItem::flags` field.
+#[derive(Debug, Copy, Clone, PartialEq, Eq, Hash)]
+#[repr(u8)]
+pub enum DBISectionMapItemFlag {
+    /// Read access
+    Read = 1 << 0,
+    /// Write access
+    Write = 1 << 1,
+    /// Execute access
+    Execute = 1 << 2,
+    /// 32-bit section
+    ThirtyTwoBit = 1 << 3,
+}
+
+/// Section type values for the `DBISectionMapItem::flags` field.
+#[derive(Debug, Copy, Clone, PartialEq, Eq, Hash)]
+#[repr(u8)]
+pub enum DBISectionMapItemSectionType {
+    /// Section type SEL
+    Sel = 1 << 0,
+    /// Section type ABS
+    Abs = 1 << 1,
+    /// Section type GROUP
+    Group = 1 << 4,
+}
+
+impl DBISectionMapItem {
+    fn parse(buf: &mut ParseBuffer<'_>) -> Result<Self> {
+        Ok(Self {
+            flags: buf.parse_u8()?,
+            section_type: buf.parse_u8()?,
+            overlay: buf.parse_u16()?,
+            group: buf.parse_u16()?,
+            section_number: buf.parse_u16()?,
+            seg_name_index: buf.parse_u16()?,
+            class_name_index: buf.parse_u16()?,
+            rva_offset: buf.parse_u32()?,
+            section_length: buf.parse_u32()?,
+        })
+    }
+}
+
+/// A `DBISectionMapIter` iterates over the section map in the DBI section, producing `DBISectionMap`s.
+#[derive(Debug)]
+pub struct DBISectionMapIter<'c> {
+    /// The section count.
+    pub sec_count: u16,
+    /// The logical section count. Typically equals sec_count, if no groups are in use. (?)
+    pub sec_count_log: u16,
+    buf: ParseBuffer<'c>,
+}
+
+impl<'c> DBISectionMapIter<'c> {
+    fn parse(mut buf: ParseBuffer<'c>) -> Result<Self> {
+        let sec_count = buf.parse_u16()?;
+        let sec_count_log = buf.parse_u16()?;
+
+        Ok(Self {
+            buf,
+            sec_count,
+            sec_count_log,
+        })
+    }
+}
+
+impl FallibleIterator for DBISectionMapIter<'_> {
+    type Item = DBISectionMapItem;
+    type Error = Error;
+
+    fn next(&mut self) -> result::Result<Option<Self::Item>, Self::Error> {
+        // see if we're at EOF
+        if self.buf.is_empty() {
+            return Ok(None);
+        }
+
+        let segmap = Self::Item::parse(&mut self.buf)?;
+        Ok(Some(segmap))
+    }
+}
+
 /// A `DbgDataHdr`, which contains a series of (optional) MSF stream numbers.
 #[derive(Debug, Copy, Clone)]
 #[allow(dead_code)] // reason = "unused fields added for completeness"
