@@ -6,8 +6,8 @@ use scroll::{ctx::TryFromCtx, Endian, Pread};
 
 use crate::common::*;
 use crate::modi::{
-    constants, CrossModuleExport, CrossModuleRef, FileChecksum, FileIndex, FileInfo, LineInfo,
-    LineInfoKind, ModuleRef,
+    constants, CrossModuleExport, CrossModuleRef, FileChecksum, FileInfo, LineInfo, LineInfoKind,
+    ModuleRef,
 };
 use crate::symbol::{BinaryAnnotation, BinaryAnnotationsIter, InlineSiteSymbol};
 use crate::FallibleIterator;
@@ -38,7 +38,9 @@ enum DebugSubsectionKind {
 impl DebugSubsectionKind {
     fn parse(value: u32) -> Result<Option<Self>> {
         if (0xf1..=0xfd).contains(&value) {
-            Ok(Some(unsafe { std::mem::transmute(value) }))
+            Ok(Some(unsafe {
+                std::mem::transmute::<u32, DebugSubsectionKind>(value)
+            }))
         } else if value == constants::DEBUG_S_IGNORE {
             Ok(None)
         } else {
@@ -149,7 +151,7 @@ pub struct InlineeSourceLine<'a> {
     extra_files: &'a [u8],
 }
 
-impl<'a> InlineeSourceLine<'a> {
+impl InlineeSourceLine<'_> {
     // TODO: Implement extra files iterator when needed.
 }
 
@@ -229,7 +231,7 @@ impl<'a> DebugInlineeLinesSubsection<'a> {
 struct DebugLinesHeader {
     /// Section offset of this line contribution.
     offset: PdbInternalSectionOffset,
-    /// See LineFlags enumeration.
+    /// See `LineFlags` enumeration.
     flags: u16,
     /// Code size of this line contribution.
     code_size: u32,
@@ -345,6 +347,7 @@ enum LineEntry {
     /// Declares a source line number.
     Number(LineNumberEntry),
     /// Declares a debugging marker.
+    #[allow(dead_code)] // reason = "the inner `LineMarkerEntry` is not (yet) accessed"
     Marker(LineMarkerEntry),
 }
 
@@ -587,7 +590,7 @@ impl FileChecksumKind {
     /// Parses the checksum kind from its raw value.
     fn parse(value: u8) -> Result<Self> {
         if value <= 3 {
-            Ok(unsafe { std::mem::transmute(value) })
+            Ok(unsafe { std::mem::transmute::<u8, FileChecksumKind>(value) })
         } else {
             Err(Error::UnimplementedFileChecksumKind(value))
         }
@@ -907,7 +910,7 @@ impl Default for CrossModuleExportIter<'_> {
     }
 }
 
-impl<'a> FallibleIterator for CrossModuleExportIter<'a> {
+impl FallibleIterator for CrossModuleExportIter<'_> {
     type Item = CrossModuleExport;
     type Error = Error;
 
@@ -944,17 +947,20 @@ impl CrossModuleExports {
 
     /// Returns the number of exported types or ids from this module.
     #[inline]
+    #[must_use]
     pub fn len(&self) -> usize {
         self.raw_exports.len()
     }
 
     /// Returns `true` if this module does not export types or ids.
     #[inline]
+    #[must_use]
     pub fn is_empty(&self) -> bool {
         self.raw_exports.is_empty()
     }
 
     /// Returns an iterator over all cross scope exports.
+    #[must_use]
     pub fn exports(&self) -> CrossModuleExportIter<'_> {
         CrossModuleExportIter {
             exports: self.raw_exports.iter(),
@@ -995,7 +1001,7 @@ pub struct LineIterator<'a> {
     last_info: Option<LineInfo>,
 }
 
-impl<'a> FallibleIterator for LineIterator<'a> {
+impl FallibleIterator for LineIterator<'_> {
     type Item = LineInfo;
     type Error = Error;
 
@@ -1127,7 +1133,7 @@ impl<'a> InlineeLineIterator<'a> {
     }
 }
 
-impl<'a> FallibleIterator for InlineeLineIterator<'a> {
+impl FallibleIterator for InlineeLineIterator<'_> {
     type Item = LineInfo;
     type Error = Error;
 
@@ -1237,6 +1243,7 @@ pub struct Inlinee<'a>(InlineeSourceLine<'a>);
 
 impl<'a> Inlinee<'a> {
     /// The index of this inlinee in the `IdInformation` stream (IPI).
+    #[must_use]
     pub fn index(&self) -> IdIndex {
         self.0.inlinee
     }
@@ -1246,6 +1253,7 @@ impl<'a> Inlinee<'a> {
     /// Note that line records are not guaranteed to be ordered by source code offset. If a
     /// monotonic order by `PdbInternalSectionOffset` or `Rva` is required, the lines have to be
     /// sorted manually.
+    #[must_use]
     pub fn lines(
         &self,
         parent_offset: PdbInternalSectionOffset,
@@ -1418,8 +1426,6 @@ impl<'a> LineProgram<'a> {
 mod tests {
     use super::*;
 
-    use std::mem;
-
     use crate::symbol::BinaryAnnotations;
 
     #[test]
