@@ -25,6 +25,8 @@ pub enum TypeData<'t> {
     Nested(NestedType<'t>),
     BaseClass(BaseClassType),
     VirtualBaseClass(VirtualBaseClassType),
+    VirtualFunctionTable(VirtualFunctionTableType<'t>),
+    VirtualTableShape(VirtualTableShapeType),
     VirtualFunctionTablePointer(VirtualFunctionTablePointerType),
     Procedure(ProcedureType),
     Pointer(PointerType),
@@ -33,6 +35,7 @@ pub enum TypeData<'t> {
     Enumerate(EnumerateType<'t>),
     Array(ArrayType),
     Union(UnionType<'t>),
+    Alias(AliasType<'t>),
     Bitfield(BitfieldType),
     FieldList(FieldList<'t>),
     ArgumentList(ArgumentList),
@@ -40,7 +43,8 @@ pub enum TypeData<'t> {
 }
 
 impl<'t> TypeData<'t> {
-    /// Return the name of this TypeData, if any
+    /// Return the name of this `TypeData`, if any
+    #[must_use]
     pub fn name(&self) -> Option<RawString<'t>> {
         let name = match self {
             Self::Class(ClassType { ref name, .. })
@@ -50,7 +54,8 @@ impl<'t> TypeData<'t> {
             | Self::Nested(NestedType { ref name, .. })
             | Self::Enumeration(EnumerationType { ref name, .. })
             | Self::Enumerate(EnumerateType { ref name, .. })
-            | Self::Union(UnionType { ref name, .. }) => name,
+            | Self::Union(UnionType { ref name, .. })
+            | Self::Alias(AliasType { ref name, .. }) => name,
             _ => return None,
         };
 
@@ -93,9 +98,14 @@ pub(crate) fn parse_type_data<'t>(buf: &mut ParseBuffer<'t>) -> Result<TypeData<
         }
 
         // https://github.com/microsoft/microsoft-pdb/issues/50#issuecomment-737890766
-        LF_STRUCTURE19 => {
+        LF_CLASS2 | LF_STRUCTURE2 | LF_INTERFACE2 => {
             let mut class = ClassType {
-                kind: ClassKind::Struct,
+                kind: match leaf {
+                    LF_CLASS2 => ClassKind::Class,
+                    LF_STRUCTURE2 => ClassKind::Struct,
+                    LF_INTERFACE2 => ClassKind::Interface,
+                    _ => unreachable!(),
+                },
                 properties: TypeProperties(buf.parse_u32()? as u16),
                 fields: parse_optional_type_index(buf)?,
                 derived_from: parse_optional_type_index(buf)?,
@@ -166,7 +176,7 @@ pub(crate) fn parse_type_data<'t>(buf: &mut ParseBuffer<'t>) -> Result<TypeData<
                 attributes: attr,
                 method_type: buf.parse()?,
                 vtable_offset: if attr.is_intro_virtual() {
-                    Some(buf.parse_u32()? as u32)
+                    Some(buf.parse_u32()?)
                 } else {
                     // yes, this is variable length
                     None
@@ -285,7 +295,7 @@ pub(crate) fn parse_type_data<'t>(buf: &mut ParseBuffer<'t>) -> Result<TypeData<
 
             loop {
                 let dim = parse_unsigned(buf)?;
-                if dim > u64::from(u32::max_value()) {
+                if dim > u64::from(u32::MAX) {
                     return Err(Error::UnimplementedFeature("u64 array sizes"));
                 }
                 dimensions.push(dim as u32);
@@ -308,7 +318,9 @@ pub(crate) fn parse_type_data<'t>(buf: &mut ParseBuffer<'t>) -> Result<TypeData<
             //println!("array: {:x}", buf);
             //println!("dimensions: {:?}", dimensions);
 
-            assert!(buf.is_empty());
+            // Vector35/binaryninja-api#6076: NativeAOT PDBs have extra data here
+            // of unknown purpose
+            //assert!(buf.is_empty());
 
             Ok(TypeData::Array(ArrayType {
                 element_type,
@@ -336,6 +348,30 @@ pub(crate) fn parse_type_data<'t>(buf: &mut ParseBuffer<'t>) -> Result<TypeData<
             Ok(TypeData::Union(union))
         }
 
+        // https://github.com/Microsoft/microsoft-pdb/blob/082c5290e5aff028ae84e43affa8be717aa7af73/include/cvinfo.h#L1669-L1673
+        LF_ALIAS | LF_ALIAS_ST => Ok(TypeData::Alias(AliasType {
+            underlying_type: buf.parse()?,
+            name: parse_string(leaf, buf)?,
+        })),
+
+        // https://github.com/microsoft/microsoft-pdb/issues/50#issuecomment-737890766
+        LF_UNION2 => {
+            let mut union = UnionType {
+                properties: TypeProperties(buf.parse_u32()? as u16),
+                fields: buf.parse()?,
+                count: buf.parse_u16()?,
+                size: parse_unsigned(buf)?,
+                name: parse_string(leaf, buf)?,
+                unique_name: None,
+            };
+
+            if union.properties.has_unique_name() {
+                union.unique_name = Some(parse_string(leaf, buf)?);
+            }
+
+            Ok(TypeData::Union(union))
+        }
+
         // https://github.com/Microsoft/microsoft-pdb/blob/082c5290e5aff028ae84e43affa8be717aa7af73/include/cvinfo.h#L2164-L2170
         LF_BITFIELD => Ok(TypeData::Bitfield(BitfieldType {
             underlying_type: buf.parse()?,
@@ -345,14 +381,46 @@ pub(crate) fn parse_type_data<'t>(buf: &mut ParseBuffer<'t>) -> Result<TypeData<
 
         // https://github.com/Microsoft/microsoft-pdb/blob/082c5290e5aff028ae84e43affa8be717aa7af73/include/cvinfo.h#L1819-L1823
         LF_VTSHAPE => {
-            // TODO
-            Err(Error::UnimplementedTypeKind(leaf))
+            let mut vtshape = VirtualTableShapeType {
+                descriptors: vec![],
+            };
+            let count = buf.parse_u16()? as usize;
+            // These are packed 4-bit values
+            for _ in 0..((count + 1) / 2) {
+                let desc: u8 = buf.parse()?;
+
+                vtshape
+                    .descriptors
+                    .push(VirtualTableShapeDescriptor::from_u4(desc & 0xF));
+                if vtshape.descriptors.len() < count {
+                    vtshape
+                        .descriptors
+                        .push(VirtualTableShapeDescriptor::from_u4(desc >> 4));
+                }
+            }
+            Ok(TypeData::VirtualTableShape(vtshape))
         }
 
         // https://github.com/Microsoft/microsoft-pdb/blob/082c5290e5aff028ae84e43affa8be717aa7af73/include/cvinfo.h#L1825-L1837
         LF_VFTABLE => {
-            // TODO
-            Err(Error::UnimplementedTypeKind(leaf))
+            let mut vftable = VirtualFunctionTableType {
+                owner: buf.parse()?,
+                base: buf.parse()?,
+                object_offset: parse_unsigned(buf)? as u32,
+                names: vec![],
+            };
+
+            let names_length = parse_unsigned(buf)? as usize;
+
+            let mut len = 0;
+            while len < names_length {
+                let s = buf.parse_cstring()?;
+                len += s.len() + 1;
+                vftable.names.push(s);
+            }
+            assert_eq!(len, names_length);
+
+            Ok(TypeData::VirtualFunctionTable(vftable))
         }
 
         // https://github.com/Microsoft/microsoft-pdb/blob/082c5290e5aff028ae84e43affa8be717aa7af73/include/cvinfo.h#L2521-L2528
@@ -377,7 +445,10 @@ pub(crate) fn parse_type_data<'t>(buf: &mut ParseBuffer<'t>) -> Result<TypeData<
                 match buf.peek_u16()? {
                     LF_INDEX => {
                         // continuation record
-                        // eat the leaf value
+                        // eat the leaf value, which we just peeked at
+                        buf.parse_u16()?;
+
+                        // eat another u16, which is padding (always 0 in files produced by MSVC)
                         buf.parse_u16()?;
 
                         // parse the TypeIndex where we continue
@@ -512,34 +583,42 @@ unsigned short  mocom       :2;     // CV_MOCOM_UDT_e
 pub struct TypeProperties(u16);
 impl TypeProperties {
     /// Indicates if a type is packed via `#pragma pack` or similar.
+    #[must_use]
     pub fn packed(self) -> bool {
         self.0 & 0x0001 != 0
     }
 
     /// Indicates if a type has constructors or destructors.
+    #[must_use]
     pub fn constructors(self) -> bool {
         self.0 & 0x0002 != 0
     }
 
     /// Indicates if a type has any overloaded operators.
+    #[must_use]
     pub fn overloaded_operators(self) -> bool {
         self.0 & 0x0004 != 0
     }
 
     /// Indicates if a type is a nested type, e.g. a `union` defined inside a `class`.
+    #[must_use]
     pub fn is_nested_type(self) -> bool {
         self.0 & 0x0008 != 0
     }
 
     /// Indicates if a type contains nested types.
+    #[must_use]
     pub fn contains_nested_types(self) -> bool {
         self.0 & 0x0010 != 0
     }
 
     /// Indicates if a class has overloaded the assignment operator.
+    #[must_use]
     pub fn overloaded_assignment(self) -> bool {
         self.0 & 0x0020 != 0
     }
+
+    #[must_use]
     pub fn overloaded_casting(self) -> bool {
         self.0 & 0x0040 != 0
     }
@@ -548,25 +627,37 @@ impl TypeProperties {
     /// placeholder until a complete Type can be built. This is necessary for e.g. self-referential
     /// data structures, but other more common declaration/definition idioms can cause forward
     /// references too.
+    #[must_use]
     pub fn forward_reference(self) -> bool {
         self.0 & 0x0080 != 0
     }
 
+    #[must_use]
     pub fn scoped_definition(self) -> bool {
         self.0 & 0x0100 != 0
     }
+
+    #[must_use]
     pub fn has_unique_name(self) -> bool {
         self.0 & 0x0200 != 0
     }
+
+    #[must_use]
     pub fn sealed(self) -> bool {
         self.0 & 0x0400 != 0
     }
+
+    #[must_use]
     pub fn hfa(self) -> u8 {
         ((self.0 & 0x1800) >> 11) as u8
     }
+
+    #[must_use]
     pub fn intrinsic_type(self) -> bool {
         self.0 & 0x1000 != 0
     }
+
+    #[must_use]
     pub fn mocom(self) -> u8 {
         ((self.0 & 0x6000) >> 14) as u8
     }
@@ -593,40 +684,101 @@ typedef enum CV_methodprop_e {
     CV_MTpurevirt       = 0x05,
     CV_MTpureintro      = 0x06
 } CV_methodprop_e;
-
 */
+
 #[derive(Debug, Copy, Clone, PartialEq, Eq)]
 pub struct FieldAttributes(u16);
 impl FieldAttributes {
     #[inline]
+    #[must_use]
     pub fn access(self) -> u8 {
         (self.0 & 0x0003) as u8
     }
+
     #[inline]
+    #[must_use]
     fn method_properties(self) -> u8 {
         ((self.0 & 0x001c) >> 2) as u8
     }
 
     #[inline]
-    pub fn is_static(self) -> bool {
-        self.method_properties() == 0x02
+    #[must_use]
+    pub fn is_vanilla(self) -> bool {
+        self.method_properties() == 0x00
     }
 
     #[inline]
+    #[must_use]
     pub fn is_virtual(self) -> bool {
         self.method_properties() == 0x01
     }
 
     #[inline]
+    #[must_use]
+    pub fn is_static(self) -> bool {
+        self.method_properties() == 0x02
+    }
+
+    #[inline]
+    #[must_use]
+    pub fn is_friend(self) -> bool {
+        self.method_properties() == 0x03
+    }
+
+    #[inline]
+    #[must_use]
+    pub fn is_intro(self) -> bool {
+        self.method_properties() == 0x04
+    }
+
+    #[inline]
+    #[must_use]
     pub fn is_pure_virtual(self) -> bool {
         self.method_properties() == 0x05
     }
 
     #[inline]
+    #[must_use]
+    pub fn is_pure_intro(self) -> bool {
+        self.method_properties() == 0x06
+    }
+
+    #[inline]
+    #[must_use]
     pub fn is_intro_virtual(self) -> bool {
         matches!(self.method_properties(), 0x04 | 0x06)
     }
 
+    #[inline]
+    #[must_use]
+    pub fn is_pseudo(self) -> bool {
+        self.0 & 0x0020 != 0
+    }
+
+    #[inline]
+    #[must_use]
+    pub fn noinherit(self) -> bool {
+        self.0 & 0x0040 != 0
+    }
+
+    #[inline]
+    #[must_use]
+    pub fn noconstruct(self) -> bool {
+        self.0 & 0x0080 != 0
+    }
+
+    #[inline]
+    #[must_use]
+    pub fn is_compgenx(self) -> bool {
+        self.0 & 0x0100 != 0
+    }
+
+    #[inline]
+    #[must_use]
+    pub fn sealed(self) -> bool {
+        self.0 & 0x0200 != 0
+    }
+
     // TODO
 }
 
@@ -652,15 +804,22 @@ typedef struct CV_funcattr_t {
 #[derive(Debug, Copy, Clone, PartialEq, Eq)]
 pub struct FunctionAttributes(u16);
 impl FunctionAttributes {
+    #[must_use]
     pub fn calling_convention(self) -> u8 {
         (self.0 & 0xff) as u8
     }
+
+    #[must_use]
     pub fn cxx_return_udt(self) -> bool {
         (self.0 & 0x0100) > 0
     }
+
+    #[must_use]
     pub fn is_constructor(self) -> bool {
         (self.0 & 0x0200) > 0
     }
+
+    #[must_use]
     pub fn is_constructor_with_virtual_bases(self) -> bool {
         (self.0 & 0x0400) > 0
     }
@@ -734,6 +893,7 @@ pub struct PointerAttributes(u32);
 
 impl PointerAttributes {
     /// Indicates the type of pointer.
+    #[must_use]
     pub fn pointer_kind(self) -> PointerKind {
         match self.0 & 0x1f {
             0x00 => PointerKind::Near16,
@@ -754,6 +914,7 @@ impl PointerAttributes {
     }
 
     /// Returns the mode of this pointer.
+    #[must_use]
     pub fn pointer_mode(self) -> PointerMode {
         match (self.0 >> 5) & 0x7 {
             0x00 => PointerMode::Pointer,
@@ -766,6 +927,7 @@ impl PointerAttributes {
     }
 
     /// Returns `true` if this points to a member (either data or function).
+    #[must_use]
     pub fn pointer_to_member(self) -> bool {
         matches!(
             self.pointer_mode(),
@@ -774,31 +936,37 @@ impl PointerAttributes {
     }
 
     /// Returns `true` if this is a flat `0:32` pointer.
+    #[must_use]
     pub fn is_flat_32(self) -> bool {
         (self.0 & 0x100) != 0
     }
 
     /// Returns `true` if this pointer is `volatile`.
+    #[must_use]
     pub fn is_volatile(self) -> bool {
         (self.0 & 0x200) != 0
     }
 
     /// Returns `true` if this pointer is `const`.
+    #[must_use]
     pub fn is_const(self) -> bool {
         (self.0 & 0x400) != 0
     }
 
     /// Returns `true` if this pointer is unaligned.
+    #[must_use]
     pub fn is_unaligned(self) -> bool {
         (self.0 & 0x800) != 0
     }
 
     /// Returns `true` if this pointer is restricted (allow aggressive opts).
+    #[must_use]
     pub fn is_restrict(self) -> bool {
         (self.0 & 0x1000) != 0
     }
 
     /// Is this a C++ reference, as opposed to a C pointer?
+    #[must_use]
     pub fn is_reference(self) -> bool {
         matches!(
             self.pointer_mode(),
@@ -807,6 +975,7 @@ impl PointerAttributes {
     }
 
     /// The size of the pointer in bytes.
+    #[must_use]
     pub fn size(self) -> u8 {
         let size = ((self.0 >> 13) & 0x3f) as u8;
         if size != 0 {
@@ -820,12 +989,58 @@ impl PointerAttributes {
         }
     }
 
-    /// Returns `true` if this is a MoCOM pointer (`^` or `%`).
+    /// Returns `true` if this is a `MoCOM` pointer (`^` or `%`).
+    #[must_use]
     pub fn is_mocom(self) -> bool {
         (self.0 & 0x40000) != 0
     }
 }
 
+/*
+typedef enum CV_VTS_desc_e {
+    CV_VTS_near         = 0x00,
+    CV_VTS_far          = 0x01,
+    CV_VTS_thin         = 0x02,
+    CV_VTS_outer        = 0x03,
+    CV_VTS_meta         = 0x04,
+    CV_VTS_near32       = 0x05,
+    CV_VTS_far32        = 0x06,
+    CV_VTS_unused       = 0x07
+} CV_VTS_desc_e;
+ */
+#[allow(unused)]
+#[repr(u8)]
+#[derive(Copy, Clone, Debug, PartialEq, Eq)]
+pub enum VirtualTableShapeDescriptor {
+    Near = 0x00,
+    Far = 0x01,
+    Thin = 0x02,
+    Outer = 0x03,
+    Meta = 0x04,
+    Near32 = 0x05,
+    Far32 = 0x06,
+    Unused = 0x07,
+}
+
+impl VirtualTableShapeDescriptor {
+    // Convert a 4-bit "u4" value in a u8 to a VirtualTableShapeDescriptor
+    // This is used in the VirtualTableShapeType parsing and is not public
+    // so we can safely assume that the value is in the correct range.
+    pub(crate) fn from_u4(val: u8) -> Self {
+        match val {
+            0x00 => VirtualTableShapeDescriptor::Near,
+            0x01 => VirtualTableShapeDescriptor::Far,
+            0x02 => VirtualTableShapeDescriptor::Thin,
+            0x03 => VirtualTableShapeDescriptor::Outer,
+            0x04 => VirtualTableShapeDescriptor::Meta,
+            0x05 => VirtualTableShapeDescriptor::Near32,
+            0x06 => VirtualTableShapeDescriptor::Far32,
+            0x07 => VirtualTableShapeDescriptor::Unused,
+            _ => unreachable!(),
+        }
+    }
+}
+
 /// The information parsed from a type record with kind
 /// `LF_CLASS`, `LF_CLASS_ST`, `LF_STRUCTURE`, `LF_STRUCTURE_ST` or `LF_INTERFACE`.
 // https://github.com/Microsoft/microsoft-pdb/blob/082c5290e5aff028ae84e43affa8be717aa7af73/include/cvinfo.h#L1631
@@ -947,6 +1162,21 @@ pub struct VirtualFunctionTablePointerType {
     pub table: TypeIndex,
 }
 
+/// The information parsed from a type record with kind `LF_VTSHAPE`.
+#[derive(Debug, Clone, PartialEq, Eq)]
+pub struct VirtualTableShapeType {
+    pub descriptors: Vec<VirtualTableShapeDescriptor>,
+}
+
+/// The information parsed from a type record with kind `LF_VFTABLE`.
+#[derive(Debug, Clone, PartialEq, Eq)]
+pub struct VirtualFunctionTableType<'t> {
+    pub owner: TypeIndex,
+    pub base: TypeIndex,
+    pub object_offset: u32,
+    pub names: Vec<RawString<'t>>,
+}
+
 /// The information parsed from a type record with kind `LF_PROCEDURE`.
 #[derive(Debug, Copy, Clone, PartialEq, Eq)]
 pub struct ProcedureType {
@@ -1023,6 +1253,13 @@ pub struct UnionType<'t> {
     pub unique_name: Option<RawString<'t>>,
 }
 
+/// The information parsed from a type record with kind `LF_ALIAS` or `LF_ALIAS_ST`.
+#[derive(Debug, Clone, PartialEq, Eq)]
+pub struct AliasType<'t> {
+    pub underlying_type: TypeIndex,
+    pub name: RawString<'t>,
+}
+
 /// The information parsed from a type record with kind `LF_BITFIELD`.
 #[derive(Debug, Copy, Clone, PartialEq, Eq)]
 pub struct BitfieldType {
@@ -1036,8 +1273,8 @@ pub struct BitfieldType {
 pub struct FieldList<'t> {
     pub fields: Vec<TypeData<'t>>,
 
-    /// Sometimes fields can't all fit in a single FieldList, in which case the FieldList
-    /// refers to another FieldList in a chain.
+    /// Sometimes fields can't all fit in a single `FieldList`, in which case the `FieldList`
+    /// refers to another `FieldList` in a chain.
     pub continuation: Option<TypeIndex>,
 }
 
